@@ -29,8 +29,7 @@ void comm_send_rules(struct arglist *);
 void comm_wait_order(struct arglist *);
 void comm_setup_plugins(struct arglist *, char *);
 void client_handler();
-void comm_send_status(struct arglist *, char *, char *, int, int);
-#ifdef ENABLE_CRYPTO_LAYER
-char *initiate_peks_key_exchange (struct arglist *, int, struct sockaddr_in *);
-#endif
+void comm_send_md5_plugins(struct arglist*);
+void plugin_send_infos(struct arglist*, int);
+
 #endif
