@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2004 Renaud Deraison
+ * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -204,12 +204,15 @@ int preferences_process(filename,prefs)
 	   
 	   buffer[sizeof(buffer) - 1] = '\0';
 	   len = strlen(buffer);
+	   if ( len == 0 ) continue;
 	   
 	   if(buffer[len-1]=='\n')
 	    {
 	     buffer[len-1]=0;
 	     len --;
 	    }
+
+	    if ( len <= 0 ) continue;
 	   
 	    if(buffer[0]=='#')continue;
 	    opt = buffer;
@@ -217,26 +220,29 @@ int preferences_process(filename,prefs)
 	    if( t == NULL )continue;
 	    else {
 	      t[0]=0;
-	      t+=sizeof(char);
-	      while(t[0]==' ')t+=sizeof(char);
+	      t++;
+	      while(t[0]==' ')t++;
 	      len = strlen(opt);
-	      while(opt[len-1]==' ')
+	      while(len > 0 && opt[len-1]==' ')
 	      {
 	       opt[len-1]= '\0';
 	       len --;
 	      }
+	      if ( len <= 0 ) continue;
 	      
 	      len = strlen(t);
-	      while(t[len-1]==' ')
+	      while(len > 0 && t[len-1]==' ')
 	      {
 	       t[len-1]= '\0';
 	       len --;
 	      }
-	      
+
+	      if ( len <= 0 ) continue;
+	      len = strlen(t);
 	      value = emalloc(len + 1);
 	      strncpy(value, t, len);
 	      arg_add_value(prefs, opt, ARG_STRING, strlen(value), value);
-#ifdef DEBUGMORE
+#if DEBUGMORE
 	      printf("%s = %s\n", opt, value);
 #endif
 	    }
